@@ -19,6 +19,6 @@
 #' summary(person)
 #' } 
 getPerson <- function(){
-    ret <- mirtCAT_post_internal(person=MCE$person, design=MCE$design)
+    ret <- mirtCAT_post_internal(person=.MCE$person, design=.MCE$design)
     ret
 }
\ No newline at end of file
